﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace FileInfoDemocSharp
{
        

    public partial class fMain : Form
    {
        string fileName;

        public fMain()
        {
            InitializeComponent();
        }

        private void fMain_Load(object sender, EventArgs e)
        {
            mnuFileSave.Enabled = false;
            mnuFileSaveAs.Enabled = false;
            mnuFileClose.Enabled = false;
            cboFileInfo.Enabled = false;

            cboFileInfo.Items.Add("Caption");
            cboFileInfo.Items.Add("Keywords");
            cboFileInfo.Items.Add("Categories");
            cboFileInfo.Items.Add("Credits");
            cboFileInfo.Items.Add("Origin");
            cboFileInfo.Items.Add("Copyright & URL");
            cboFileInfo.Items.Add("Creator Contact");
            cboFileInfo.Items.Add("EXIF Data");
            cboFileInfo.Text = "No image loaded";

            grpCaption.Visible = false;
            grpKeywords.Visible = false;
            grpCategories.Visible = false;
            grpCredits.Visible = false;
            grpOrigin.Visible = false;
            grpCopyright.Visible = false;
            grpContact.Visible = false;
            grpExif.Visible = false;
            cmdApply.Visible = false;

            for (int i = 1; i <= 8; i++)
                cboUrgency.Items.Add(i.ToString());
            cboUrgency.Items.Add("None");
            cboUrgency.Text = "None";

            axImageBox1.AutoZoom = true;
        }

        private void mnuFileOpen_Click(object sender, EventArgs e)
        {
            dlgOpen.Title = "Load JPEG or TIFF File";
            dlgOpen.Filter = "JPEG Files (*.jpg, *.jpeg, *.jpe)|*.jpg;*.jpeg;*.jpe|TIFF Files (*.tif, *.tiff)|*.tif;*.tiff";
            if (dlgOpen.ShowDialog() != DialogResult.Cancel)
            {
                fileName = dlgOpen.FileName;
                axImageBox1.LoadFromFile(fileName);
                mnuFileSave.Enabled = true;
                mnuFileSaveAs.Enabled = true;
                mnuFileClose.Enabled = true;
                cboFileInfo.Enabled = true;
                cboFileInfo.Text = "Caption";
                updateDisplay();
                readFileInfo();
            }
        }

        private void updateDisplay()
        {
            grpCaption.Visible = false;
            grpKeywords.Visible = false;
            grpCategories.Visible = false;
            grpCredits.Visible = false;
            grpOrigin.Visible = false;
            grpCopyright.Visible = false;
            grpContact.Visible = false;
            grpExif.Visible = false;
            cmdApply.Visible = false;

            if (axImageBox1.ImageLoaded)
            {
                cmdApply.Visible = true;
                switch (cboFileInfo.Text)
                {
                    case "Caption":
                        grpCaption.Visible = true;
                        break;
                    case "Keywords":
                        grpKeywords.Visible = true;
                        break;
                    case "Categories":
                        grpCategories.Visible = true;
                        break;
                    case "Credits":
                        grpCredits.Visible = true;
                        break;
                    case "Origin":
                        grpOrigin.Visible = true;
                        break;
                    case "Copyright & URL":
                        grpCopyright.Visible = true;
                        break;
                    case "Creator Contact":
                        grpContact.Visible = true;
                        break;
                    case "EXIF Data":
                        grpExif.Visible = true;
                        cmdApply.Visible = false;
                        break;
                }

            }
        }

        private void cboFileInfo_SelectedIndexChanged(object sender, EventArgs e)
        {
            updateDisplay();
        }

        private void cmdKeywordAdd_Click(object sender, EventArgs e)
        {
            if (txtKeywordAdd.Text != "")
            {
                lstKeywords.Items.Add(txtKeywordAdd.Text);
                txtKeywordAdd.Text = "";
            }
        }

        private void cmdSupCatAdd_Click(object sender, EventArgs e)
        {
            if (txtSupCatAdd.Text != "")
            {
                lstSupCats.Items.Add(txtSupCatAdd.Text);
                txtSupCatAdd.Text = "";
            }
        }

        private void cmdApply_Click(object sender, EventArgs e)
        {
            writeFileInfo();
        }

        private void cmdDelKeyword_Click(object sender, EventArgs e)
        {
            int i = lstKeywords.SelectedIndex;
            if (i != -1)
                lstKeywords.Items.RemoveAt(i);
        }

        private void cmdDelSupCat_Click(object sender, EventArgs e)
        {
            int i = lstSupCats.SelectedIndex;
            if (i != -1)
                lstSupCats.Items.RemoveAt(i);
        }

        private void cmdExifAdd_Click(object sender, EventArgs e)
        {
            fAdd addForm = new fAdd();
            addForm.ShowDialog();
            addForm.Dispose();

            if (!axImageBox1.ExifSetAttribute(globals.exifAttName, globals.exifAttValue))
                MessageBox.Show("Invalid Exif Attribute Specification");

            exifUpdate();
        }

        private void cmdExifDelete_Click(object sender, EventArgs e)
        {
            fDel delForm = new fDel();
            delForm.ShowDialog();
            delForm.Dispose();

            if (!axImageBox1.ExifDelete(globals.exifAttName))
                MessageBox.Show("Invalid Exif Attribute Specification");

            exifUpdate();
        }

        private void exifUpdate()
        {
            lstExif.Items.Clear();
            for (int i = 0; i < axImageBox1.ExifCount; i++)
                lstExif.Items.Add(axImageBox1.get_ExifName(i) + ": " + axImageBox1.get_ExifValueByIndex(i));
        }

        private void cmdToday_Click(object sender, EventArgs e)
        {
            txtDate.Text = DateTime.Now.ToShortDateString();
        }

        private void mnuFileSave_Click(object sender, EventArgs e)
        {
            try
            {
                axImageBox1.SaveToFile(fileName);
            }
            catch (Exception err)
            {
                MessageBox.Show(err.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void mnuFileSaveAs_Click(object sender, EventArgs e)
        {
            dlgSave.Title = "Save As";
            dlgSave.Filter = "JPEG Files (*.jpg, *.jpeg, *.jpe)|*.jpg;*.jpeg;*.jpe|TIFF Files (*.tif, *.tiff)|*.tif;*.tiff";
            dlgSave.FileName = "";
            if (dlgSave.ShowDialog() != System.Windows.Forms.DialogResult.Cancel)
            {
                fileName = dlgSave.FileName;
                try
                {
                    axImageBox1.SaveToFile(fileName);
                }
                catch (Exception err)
                {
                    MessageBox.Show(err.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }

        }

        private void mnuFileClose_Click(object sender, EventArgs e)
        {
            axImageBox1.Clear();
            fileName = "";
            mnuFileSave.Enabled = false;
            mnuFileSaveAs.Enabled = false;
            mnuFileClose.Enabled = false;
            cboFileInfo.Enabled = false;
            cboFileInfo.Text = "No Image Loaded";
            updateDisplay();
        }

        private void mnuFileExit_Click(object sender, EventArgs e)
        {
            fMain.ActiveForm.Close();
        }

        private void readFileInfo()
        {
            if (axImageBox1.ImageLoaded)
            {
                //Caption
                txtCaption.Text = axImageBox1.FFO_Caption;
                txtCaptionWriter.Text = axImageBox1.FFO_CaptionWriter;
                txtHeadline.Text = axImageBox1.FFO_Headline;
                txtSpecInst.Text = axImageBox1.FFO_SpecialInstructions;

                //Keywords
                lstKeywords.Items.Clear();
                for (int i = 0; i < axImageBox1.FFO_KeywordsCount; i++)
                    lstKeywords.Items.Add(axImageBox1.get_FFO_Keywords(i));

                //Categories
                txtCategory.Text = axImageBox1.FFO_Category;
                lstSupCats.Items.Clear();
                for (int i = 0; i < axImageBox1.FFO_SuppCatCount; i++)
                    lstSupCats.Items.Add(axImageBox1.get_FFO_SuppCat(i));
                if (axImageBox1.FFO_Urgency != 0)
                    cboUrgency.Text = axImageBox1.FFO_Urgency.ToString();
                else
                    cboUrgency.Text = "None";

                //Credits
                txtByline.Text = axImageBox1.FFO_Byline;
                txtBylineTitle.Text = axImageBox1.FFO_BylineTitle;
                txtCredit.Text = axImageBox1.FFO_Credit;
                txtSource.Text = axImageBox1.FFO_Source;

                //Origin
                txtObjectName.Text = axImageBox1.FFO_ObjectName;
                if (axImageBox1.FFO_DateCreated.ToOADate() != 0)
                    txtDate.Text = axImageBox1.FFO_DateCreated.ToShortDateString();
                txtCity.Text = axImageBox1.FFO_City;
                txtProvince.Text = axImageBox1.FFO_ProvinceState;
                txtCountry.Text = axImageBox1.FFO_CountryName;
                txtOTR.Text = axImageBox1.FFO_OTR;

                //Copyright & URL
                if (axImageBox1.FFO_CopyrightFlag)
                    chkIsCopyright.Checked = true;
                else
                    chkIsCopyright.Checked = false;
                txtCopyright.Text = axImageBox1.FFO_CopyrightNotice;
                txtImageURL.Text = axImageBox1.FFO_ImageURL;

                //Creator Contact
                txtCreator.Text = axImageBox1.FFO_Author;
                txtAddress.Text = axImageBox1.FFO_CiAdrExtAdr;
                txtCity2.Text = axImageBox1.FFO_CiAdrCity;
                txtRegion.Text = axImageBox1.FFO_CiAdrRegion;
                txtPostCode.Text = axImageBox1.FFO_CiAdrPcode;
                txtCountry2.Text = axImageBox1.FFO_CiAdrCtry;

                //Exif Data
                lstExif.Items.Clear();
                for (int i = 0; i < axImageBox1.ExifCount; i++)
                    lstExif.Items.Add(axImageBox1.get_ExifName(i) + ": " + axImageBox1.get_ExifValueByIndex(i));
            }
        }

        private void writeFileInfo()
        {
            if (axImageBox1.ImageLoaded)
            {
                //Caption
                axImageBox1.FFO_Caption = txtCaption.Text;
                axImageBox1.FFO_CaptionWriter = txtCaptionWriter.Text;
                axImageBox1.FFO_Headline = txtHeadline.Text;
                axImageBox1.FFO_SpecialInstructions = txtSpecInst.Text;

                //Keywords
                axImageBox1.FFO_KeywordsClear();
                for (int i = 0; i < lstKeywords.Items.Count; i++)
                    axImageBox1.FFO_KeywordsAdd(lstKeywords.Items[i].ToString());

                //Categories
                axImageBox1.FFO_Category = txtCategory.Text;
                axImageBox1.FFO_SuppCatClear();
                for (int i = 0; i < lstSupCats.Items.Count; i++)
                    axImageBox1.FFO_SuppCatAdd(lstSupCats.Items[i].ToString());
                if (cboUrgency.Text == "None")
                    axImageBox1.FFO_Urgency = 0;
                else
                    axImageBox1.FFO_Urgency = cboUrgency.SelectedIndex + 1;

                //Credits
                axImageBox1.FFO_Byline = txtByline.Text;
                axImageBox1.FFO_BylineTitle = txtBylineTitle.Text;
                axImageBox1.FFO_Credit = txtCredit.Text;
                axImageBox1.FFO_Source = txtSource.Text;

                //Origin
                axImageBox1.FFO_ObjectName = txtObjectName.Text;
                if (txtDate.Text == "")
                    axImageBox1.FFO_DateCreated = DateTime.FromOADate(0);
                else
                    axImageBox1.FFO_DateCreated = DateTime.Parse(txtDate.Text);
                axImageBox1.FFO_City = txtCity.Text;
                axImageBox1.FFO_ProvinceState = txtProvince.Text;
                axImageBox1.FFO_CountryName = txtCountry.Text;
                axImageBox1.FFO_OTR = txtOTR.Text;

                //Creator Contact
                axImageBox1.FFO_Author = txtCreator.Text;
                axImageBox1.FFO_CiAdrExtAdr = txtAddress.Text;
                axImageBox1.FFO_CiAdrCity = txtCity2.Text;
                axImageBox1.FFO_CiAdrRegion = txtRegion.Text;
                axImageBox1.FFO_CiAdrPcode = txtPostCode.Text;
                axImageBox1.FFO_CiAdrCtry = txtCountry2.Text;

            }
        }

        private void mnuHelpAbout_Click(object sender, EventArgs e)
        {
            axImageBox1.AboutBox();
        }


    }
}
